@@ -3,7 +3,7 @@ use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 use Module::cpmfile::Prereqs;
 use Module::cpmfile::Util 'merge_version';
@@ -61,7 +61,10 @@ sub prereqs {
 
 sub features {
     my $self = shift;
-    $self->{features};
+    if (%{$self->{features}}) {
+        return $self->{features};
+    }
+    return;
 }
 
 sub _feature_prereqs {
@@ -77,25 +80,25 @@ sub _feature_prereqs {
 
 sub effective_requirements {
     my ($self, $feature_ids, $phases, $types) = @_;
-    my %requirement;
+    my %req;
     for my $prereqs ($self->{prereqs}, $self->_feature_prereqs($feature_ids)) {
         $prereqs->walk($phases, $types, sub {
             my (undef, undef, $package, $options) = @_;
-            if (exists $requirement{$package}) {
-                my $v1 = $requirement{$package}{version} || 0;
+            if (exists $req{$package}) {
+                my $v1 = $req{$package}{version} || 0;
                 my $v2 = $options->{version} || 0;
                 my $version  = merge_version $v1, $v2;
-                $requirement{$package} = +{
-                    %{$requirement{$package}},
+                $req{$package} = +{
+                    %{$req{$package}},
                     %$options,
                     $version ? (version => $version) : (),
                 };
             } else {
-                $requirement{$package} = $options;
+                $req{$package} = $options;
             }
         });
     }
-    \%requirement;
+    \%req;
 }
 
 1;
